%define anolis_release 3

Name: orangefs
Version: 2.9.8
Release: %{anolis_release}%{?dist}
Summary: Parallel network file system client
URL: https://www.orangefs.org/
License: LGPLv2+ and LGPLv2 and BSD and MIT and zlib
BuildRequires: make
BuildRequires:  gcc
BuildRequires: automake
BuildRequires: bison flex libattr-devel openssl-devel
BuildRequires: perl(Math::BigInt) perl(Getopt::Long) perl(Term::ReadLine) perl(FindBin)
BuildRequires: systemd
BuildRequires: libselinux-devel
BuildRequires: lmdb-devel
BuildRequires: fuse-devel
BuildRequires: libibverbs-devel
BuildRequires: texlive latex2html ghostscript-tools-dvipdf
BuildRequires: texlive-dvips

Source0: https://github.com/waltligon/orangefs/archive/v.%{version}/%{name}-%{version}.tar.gz
Source1: orangefs-server.service
Source2: orangefs-client.service
Source3: orangefs.conf
Source4: pvfs2tab
Patch0: orangefs-genconfig.patch
Patch1: orangefs-lmdb.patch
Patch2: orangefs-no-start-stop.patch
Patch3: orangefs-autotools-2.71.patch
Patch4: orangefs-configure-c99.patch

%global _hardened_build 1

%global desc OrangeFS (formerly PVFS2) is a high-performance parallel \
network file system designed for use on high performance computing \
systems.  It provides very high performance access to disk storage for \
parallel applications.  It is accessible through a variety of \
interfaces, including the native OrangeFS library, the kernel, FUSE, \
and MPI-IO. \
\
This package provides the pvfs2-client-core which is required to use \
the kernel module.

# Workaround for -fcommon issue
# https://github.com/waltligon/orangefs/issues/80
%define _legacy_common_support 1

%description
%desc

%prep
%autosetup -n orangefs-v.%version -p1

rm -r src/apps/devel/lmdb
rm -r src/common/lmdb

mv doc/man/pvfs2.conf.5 doc/man/orangefs.conf.5

autoupdate -I maint/config
autoreconf -vif -I maint/config

%build
export LDFLAGS="%{optflags} -Wl,--as-needed"
%configure --enable-external-lmdb --enable-shared --disable-static \
   --enable-fuse --disable-usrint --with-db-backend=lmdb --with-openib=/usr
%make_build
make docs

%install
%make_install
mkdir -p %{buildroot}%{_docdir}/orangefs
install -p -m 644 doc/*.pdf %{buildroot}%{_docdir}/orangefs
mkdir -p %{buildroot}%{_docdir}/orangefs/coding
install -p -m 644 doc/coding/*.pdf %{buildroot}%{_docdir}/orangefs/coding
mkdir -p %{buildroot}%{_docdir}/orangefs/design
install -p -m 644 doc/design/*.pdf %{buildroot}%{_docdir}/orangefs/design
mkdir -p %{buildroot}%{_docdir}/orangefs/random
install -p -m 644 doc/random/*.pdf %{buildroot}%{_docdir}/orangefs/random
install -p -m 644 COPYING %{buildroot}%{_docdir}/orangefs
mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 %{SOURCE1} %{buildroot}%{_unitdir}
install -p -m 644 %{SOURCE2} %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sharedstatedir}/orangefs
mkdir -p %{buildroot}%{_sysconfdir}/orangefs
install -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/orangefs
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}

%generate_compatibility_deps

%files
%dir %{_docdir}/orangefs
%license %{_docdir}/orangefs/COPYING
%config(noreplace) %{_sysconfdir}/pvfs2tab
%{_bindir}/pvfs2-check-server
%{_bindir}/pvfs2-chmod
%{_bindir}/pvfs2-chown
%{_bindir}/pvfs2-cp
%{_bindir}/pvfs2-drop-caches
%{_bindir}/pvfs2-fs-dump
%{_bindir}/pvfs2-fsck
%{_bindir}/pvfs2-get-uid
%{_bindir}/pvfs2-getmattr
%{_bindir}/pvfs2-ln
%{_bindir}/pvfs2-ls
%{_bindir}/pvfs2-lsplus
%{_bindir}/pvfs2-mkdir
%{_bindir}/pvfs2-perf-mon-example
%{_bindir}/pvfs2-perf-mon-snmp
%{_bindir}/pvfs2-perror
%{_bindir}/pvfs2-ping
%{_bindir}/pvfs2-remove-object
%{_bindir}/pvfs2-set-debugmask
%{_bindir}/pvfs2-set-eventmask
%{_bindir}/pvfs2-set-mode
%{_bindir}/pvfs2-set-perf-history
%{_bindir}/pvfs2-set-perf-interval
%{_bindir}/pvfs2-set-sync
%{_bindir}/pvfs2-set-turn-off-timeouts
%{_bindir}/pvfs2-setmattr
%{_bindir}/pvfs2-stat
%{_bindir}/pvfs2-statfs
%{_bindir}/pvfs2-touch
%{_bindir}/pvfs2-validate
%{_bindir}/pvfs2-viewdist
%{_bindir}/pvfs2-write
%{_bindir}/pvfs2-xattr
%{_sbindir}/pvfs2-client
%{_sbindir}/pvfs2-client-core
%{_unitdir}/orangefs-client.service
%{_libdir}/libpvfs2.so.2
%{_libdir}/libpvfs2.so.2.9.7
%{_mandir}/man1/getmattr.1.zst
%{_mandir}/man1/pvfs2-client-core.1.zst
%{_mandir}/man1/pvfs2-client.1.zst
%{_mandir}/man1/pvfs2-cp.1.zst
%{_mandir}/man1/pvfs2-check-server.1.zst
%{_mandir}/man1/pvfs2-chmod.1.zst
%{_mandir}/man1/pvfs2-chown.1.zst
%{_mandir}/man1/pvfs2-drop-caches.1.zst
%{_mandir}/man1/pvfs2-fs-dump.1.zst
%{_mandir}/man1/pvfs2-fsck.1.zst
%{_mandir}/man1/pvfs2-get-uid.1.zst
%{_mandir}/man1/pvfs2-getmattr.1.zst
%{_mandir}/man1/pvfs2-ln.1.zst
%{_mandir}/man1/pvfs2-ls.1.zst
%{_mandir}/man1/pvfs2-lsplus.1.zst
%{_mandir}/man1/pvfs2-mkdir.1.zst
%{_mandir}/man1/pvfs2-perf-mon-example.1.zst
%{_mandir}/man1/pvfs2-perf-mon-snmp.1.zst
%{_mandir}/man1/pvfs2-perror.1.zst
%{_mandir}/man1/pvfs2-ping.1.zst
%{_mandir}/man1/pvfs2-remove-object.1.zst
%{_mandir}/man1/pvfs2-rm.1.zst
%{_mandir}/man1/pvfs2-set-debugmask.1.zst
%{_mandir}/man1/pvfs2-set-eventmask.1.zst
%{_mandir}/man1/pvfs2-set-mode.1.zst
%{_mandir}/man1/pvfs2-set-perf-history.1.zst
%{_mandir}/man1/pvfs2-set-perf-interval.1.zst
%{_mandir}/man1/pvfs2-set-sync.1.zst
%{_mandir}/man1/pvfs2-set-turn-off-timeouts.1.zst
%{_mandir}/man1/pvfs2-setmattr.1.zst
%{_mandir}/man1/pvfs2-stat.1.zst
%{_mandir}/man1/pvfs2-statfs.1.zst
%{_mandir}/man1/pvfs2-touch.1.zst
%{_mandir}/man1/pvfs2-validate.1.zst
%{_mandir}/man1/pvfs2-viewdist.1.zst
%{_mandir}/man1/pvfs2-write.1.zst
%{_mandir}/man1/pvfs2-xattr.1.zst
%{_mandir}/man1/pvfs2.1.zst
%{_mandir}/man1/setmattr.1.zst
%{_mandir}/man5/pvfs2tab.5.zst
%dir %{abidir}
%{abidir}/libpvfs2.dump
%{abidir}/pvfs2-chmod-option.list
%{abidir}/pvfs2-chown-option.list
%{abidir}/pvfs2-client-core-option.list
%{abidir}/pvfs2-client-option.list
%{abidir}/pvfs2-get-uid-option.list
%{abidir}/pvfs2-ln-option.list
%{abidir}/pvfs2-ls-option.list
%{abidir}/pvfs2-mkdir-option.list
%{abidir}/pvfs2-perror-option.list
%{abidir}/pvfs2-remove-object-option.list
%{abidir}/pvfs2-set-debugmask-option.list
%{abidir}/pvfs2-stat-option.list
%{abidir}/pvfs2-validate-option.list

%package devel
Summary: Parallel network file system development libraries
Requires: %{name} = %{version}-%{release}

%description devel
%desc

This package contains the headers and libraries necessary for client
development.

%files devel
%{_bindir}/pvfs2-config
%{_includedir}/orange.h
%{_includedir}/pvfs2-compat.h
%{_includedir}/pvfs2-debug.h
%{_includedir}/pvfs2-encode-stubs.h
%{_includedir}/pvfs2-hint.h
%{_includedir}/pvfs2-mgmt.h
%{_includedir}/pvfs2-mirror.h
%{_includedir}/pvfs2-request.h
%{_includedir}/pvfs2-sysint.h
%{_includedir}/pvfs2-types.h
%{_includedir}/pvfs2-usrint.h
%{_includedir}/pvfs2-util.h
%{_includedir}/pvfs2.h
%{_libdir}/libpvfs2.so

%package server
Summary: Parallel network file system server
Requires: %{name} = %{version}-%{release}
Requires: perl(Math::BigInt)

%description server
%desc

This package contains the server.

%files server
%dir %{_sysconfdir}/orangefs
%config(noreplace) %{_sysconfdir}/orangefs/orangefs.conf
%{_bindir}/pvfs2-genconfig
%{_bindir}/pvfs2-mkspace
%{_bindir}/pvfs2-showcoll
%{_sbindir}/pvfs2-server
%{_unitdir}/orangefs-server.service
%{_mandir}/man1/pvfs2-genconfig.1.zst
%{_mandir}/man1/pvfs2-mkspace.1.zst
%{_mandir}/man1/pvfs2-server.1.zst
%{_mandir}/man1/pvfs2-showcoll.1.zst
%{_mandir}/man5/orangefs.conf.5.zst
%dir %{_sharedstatedir}/orangefs
%{abidir}/pvfs2-genconfig-option.list
%{abidir}/pvfs2-mkspace-option.list
%{abidir}/pvfs2-showcoll-option.list
%{abidir}/pvfs2-server-option.list

%package fuse
Summary: Parallel network file system FUSE client
Requires: %{name} = %{version}-%{release}

%description fuse
%desc
This package contains the FUSE client.

%files fuse
%{_bindir}/pvfs2fuse

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.

%files doc
%doc ChangeLog AUTHORS CREDITS INSTALL README README.name_change
%dir %{_docdir}/orangefs/coding
%{_docdir}/orangefs/coding/developer-guidelines.pdf
%dir %{_docdir}/orangefs/design
%{_docdir}/orangefs/design/bmi-design.pdf
%{_docdir}/orangefs/design/concepts.pdf
%{_docdir}/orangefs/design/distributions.pdf
%{_docdir}/orangefs/design/flow-design.pdf
%{_docdir}/orangefs/design/fs-semantics.pdf
%{_docdir}/orangefs/design/handle-allocator.pdf
%{_docdir}/orangefs/design/pvfs2-client.pdf
%{_docdir}/orangefs/design/pvfs2-trove-usage.pdf
%{_docdir}/orangefs/design/trove-dbpf.pdf
%{_docdir}/orangefs/design/request-design.pdf
%{_docdir}/orangefs/design/storage-interface.pdf
%{_docdir}/orangefs/pvfs2-ha.pdf
%{_docdir}/orangefs/pvfs2-ha-heartbeat-v2.pdf
%{_docdir}/orangefs/pvfs2-faq.pdf
%{_docdir}/orangefs/pvfs2-quickstart.pdf
%{_docdir}/orangefs/pvfs2-status.pdf
%{_docdir}/orangefs/pvfs2-tuning.pdf
%dir %{_docdir}/orangefs/random
%{_docdir}/orangefs/random/SystemInterfaceTesting.pdf
%{_docdir}/orangefs/pvfs2-guide.pdf

%changelog
* Fri Mar 14 2025 wangzhe <wanglan.wz@alibaba-inc.com> - 2.9.8-3
- change to use fuse

* Mon Dec 18 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.9.8-2
- rebuild

* Wed Mar 29 2023 happy_orange <songnannan@linux.alibaba.com> - 2.9.8-1
- init package
